
Authors
=======

Main developer: Wolfgang Kopp `@wkopp <https://github.com/wkopp>`_

We are greatful for contributions from

* `@Annalaura94 <https://github.com/Annalaura94>`_ for advancing the filtering options of the GenomicIndexer and for developing `plotGenomeTrack`.
* `@remomomo <https://github.com/remomomo>`_ introducing RandomShift and suggesting how to improve the efficiency for Cover.export_to_bigwig.
